import { useState, useEffect } from 'react'
import withLayout from '@/layout'
import { ScrollView } from '@tarojs/components'
import '@/assets/css/iconfont.css'
import Spin from '@/components/Spin/Spin2'
import { fetch } from '@/utils/request'
import { API_ITEMS_DETAIL, API_PROJECT_TREND_LIST, API_ACTIVITY_GROUP, API_LIVE_LIST, API_NEWS_LIST } from '@/constants/api'
import DetailBottom from './components/DetailBottom/index'
import Banner from './components/Banner/index'
import BasicInfo from './components/BasicInfo/index'
import SpecialPriceHouse from './components/SpecialPriceHouse/index'
import ProjectDynamic from './components/ProjectDynamic/index'
import PropertyConsultant from './components/PropertyConsultant/index'
import Periphery from './components/Periphery/index'
import HouseTypeIntro from './components/HouseTypeIntro/index'
import MarketingActivity from './components/MarketingActivity/index'
import LivingActivity from './components/LivingActivity/index'
import News from './components/News/index'
import Pictures from './components/Pictures/index'

import './index.scss'

export default withLayout((props) => {
  const { id } = props.router.params

  const [DetailInfo, setDetailInfo] = useState({})
  const [PictureList, setPictureList] = useState([])
  const [NewsList, setNewsList] = useState([])

  const [IsPull, setPull] = useState(false)
  const [PullTimer, setPullTimer] = useState(null)

  useEffect(() => {
    // 获取楼盘信息
    fetch({ url: `${API_ITEMS_DETAIL}/${id}`, spin: true }).then((res) => {
      setDetailInfo(res || {})
      
      if (res?.buildingApartment) {
        const List = res.buildingApartment.filter(item => item.apartmentType === 'photo')
        setPictureList(List.filter(item => item.buildingImgList.length > 0))
      }
    }).catch((err) => {
      console.error(err)
    })

    // 获取资讯列表
    fetch({ url: API_NEWS_LIST, payload: { buildingId: id, pageSize: 2, pageNum: 1 } }).then((res) => {
      setNewsList(res.records || [])
    })
  }, [id])

  const PageRefresh = () => { // 页面下拉刷新回调
    setPull(true)
  }

  useEffect(() => { // 下拉刷新触发
    if (IsPull) {
      clearTimeout(PullTimer)
      setPullTimer(setTimeout(() => {
        setPull(false)
      }, 2000))
    }
  }, [IsPull])

  return (
    <view className='Page buildingDetail flex-v'>
      <view className='flex-item'>
        <view>
          <ScrollView scroll-y refresher-enabled={false} refresher-triggered={IsPull} onrefresherrefresh={PageRefresh} refresher-background='#f8f8f8'>
            <view className='PageContent'>

              {/* banner */}
              <view className='BannerContainer'>
                <view>
                  <view>
                    <Banner List={DetailInfo?.panoramaList}></Banner>
                  </view>
                </view>
              </view>

              {/* content */}
              <view className='DetailContent'>

                {/* 基本信息 */}
                <view className='BasicInfo'>
                  <BasicInfo Info={DetailInfo}></BasicInfo>
                </view>

                {/* 特价房源 */}
                <view className='SpecialPriceHouse' style={{minHeight: 0}}>
                  <SpecialPriceHouse List={DetailInfo?.specialRoomList}></SpecialPriceHouse>
                </view>

                {/* 项目动态 */}
                <view className='ProjectDynamic' style={{minHeight: 0}}>
                  <ProjectDynamic List={DetailInfo?.trendList}></ProjectDynamic>
                </view>

                {/* 置业顾问 */}
                <view className='PropertyConsultant' style={{minHeight: 0}}>
                  <PropertyConsultant List={DetailInfo?.consultants}></PropertyConsultant>
                </view>

                {/* 位置及周边 */}
                <view className='Periphery' style={{minHeight: 0}}>
                  <Periphery Info={DetailInfo}></Periphery>
                </view>

                {/* 户型介绍 */}
                <view className='HouseTypeIntro' style={{minHeight: 0}}>
                  <HouseTypeIntro Info={DetailInfo?.buildingApartment}></HouseTypeIntro>
                </view>

                {/* 营销活动 */}
                <view className='MarketingActivity' style={{minHeight: 0}}>
                  <MarketingActivity Info={DetailInfo}></MarketingActivity>
                </view>

                {/* 直播活动 */}
                <view className='LivingActivity' style={{minHeight: 0}}>
                  <LivingActivity List={DetailInfo?.liveActivityList}></LivingActivity>
                </view>

                {/* 新鲜资讯 */}
                <view className='News' style={{minHeight: 0}}>
                  <News List={NewsList}></News>
                </view>

                {/* 相册 */}
                <view className='Pictures' style={{ display: PictureList.length ? 'block' : 'none' }}>
                  <Pictures List={PictureList}></Pictures>
                </view>

              </view>

            </view>
          </ScrollView>
        </view>
      </view>

      <view className='PageBottom'>
        <DetailBottom></DetailBottom>
      </view>

    </view>
  )
})
